/**
 * Copyright (c) 2016-2018 Thales Global Services S.A.S.
 * This program and the accompanying materials are made
 * available under the terms of the Eclipse Public License 2.0
 * which is available at https://www.eclipse.org/legal/epl-2.0/
 * 
 * SPDX-License-Identifier: EPL-2.0
 * 
 * Contributors:
 *   Abel Hegedus, Tamas Borbas, Peter Lunk, Daniel Segesdi (IncQuery Labs Ltd.) - initial API and implementation
 */
package org.eclipse.emf.diffmerge.patch.api.filters;

import com.google.common.base.Objects;
import com.google.common.base.Preconditions;
import org.eclipse.emf.diffmerge.patch.AttributeEntry;
import org.eclipse.emf.diffmerge.patch.ElementEntry;
import org.eclipse.emf.diffmerge.patch.ReferenceEntry;
import org.eclipse.emf.diffmerge.patch.StructuralFeatureEntry;
import org.eclipse.emf.diffmerge.patch.api.IModelPatchEntryFilter;
import org.eclipse.emf.diffmerge.patch.api.ModelPatchEntry;
import org.eclipse.emf.diffmerge.patch.api.ModelPatchEntryProperty;
import org.eclipse.xtend.lib.annotations.AccessorType;
import org.eclipse.xtend.lib.annotations.Accessors;
import org.eclipse.xtext.xbase.lib.Pure;

@SuppressWarnings("all")
public class EntryPropertyFilter implements IModelPatchEntryFilter {
  @Accessors(AccessorType.PUBLIC_GETTER)
  private ModelPatchEntryProperty filteredProperty;
  
  @Accessors(AccessorType.PUBLIC_GETTER)
  private String filteredValue;
  
  public EntryPropertyFilter(final ModelPatchEntryProperty filteredProperty, final String filteredValue) {
    Preconditions.<ModelPatchEntryProperty>checkNotNull(filteredProperty);
    Preconditions.<String>checkNotNull(filteredValue);
    this.filteredProperty = filteredProperty;
    this.filteredValue = filteredValue;
  }
  
  @Override
  public boolean isEntryFiltered(final ModelPatchEntry entry) {
    boolean result = false;
    final ModelPatchEntryProperty filteredProperty = this.filteredProperty;
    if (filteredProperty != null) {
      switch (filteredProperty) {
        case CONTEXT:
          String _identifier = entry.getContext().getIdentifier();
          boolean _equals = Objects.equal(this.filteredValue, _identifier);
          result = _equals;
          break;
        case FEATURE:
          if ((entry instanceof StructuralFeatureEntry)) {
            String _identifier_1 = ((StructuralFeatureEntry)entry).getFeature().getIdentifier();
            boolean _equals_1 = Objects.equal(this.filteredValue, _identifier_1);
            result = _equals_1;
          }
          break;
        case TARGET:
          if ((entry instanceof ReferenceEntry)) {
            String _identifier_2 = ((ReferenceEntry)entry).getTarget().getIdentifier();
            boolean _equals_2 = Objects.equal(this.filteredValue, _identifier_2);
            result = _equals_2;
          }
          break;
        case TYPE:
          if ((entry instanceof ElementEntry)) {
            String _identifier_3 = ((ElementEntry)entry).getType().getIdentifier();
            boolean _equals_3 = Objects.equal(this.filteredValue, _identifier_3);
            result = _equals_3;
          }
          break;
        case VALUE:
          if ((entry instanceof AttributeEntry)) {
            String _value = ((AttributeEntry)entry).getValue();
            boolean _equals_4 = Objects.equal(this.filteredValue, _value);
            result = _equals_4;
          }
          break;
        default:
          break;
      }
    }
    return result;
  }
  
  @Pure
  public ModelPatchEntryProperty getFilteredProperty() {
    return this.filteredProperty;
  }
  
  @Pure
  public String getFilteredValue() {
    return this.filteredValue;
  }
}
