/**
 * Copyright (c) 2016-2018 Thales Global Services S.A.S.
 * This program and the accompanying materials are made
 * available under the terms of the Eclipse Public License 2.0
 * which is available at https://www.eclipse.org/legal/epl-2.0/
 * 
 * SPDX-License-Identifier: EPL-2.0
 * 
 * Contributors:
 *   Abel Hegedus, Tamas Borbas, Balazs Grill, Peter Lunk, Daniel Segesdi (IncQuery Labs Ltd.) - initial API and implementation
 */
package org.eclipse.emf.diffmerge.patch.runtime;

import com.google.common.base.Preconditions;
import org.eclipse.emf.diffmerge.patch.api.ModelPatch;
import org.eclipse.emf.diffmerge.patch.api.PatchApplication;
import org.eclipse.emf.diffmerge.patch.runtime.EMFPatchApplication;
import org.eclipse.emf.diffmerge.patch.runtime.identifier.IdentifiedEMFObjectLocator;
import org.eclipse.emf.diffmerge.patch.runtime.modelaccess.EMFModelAccess;
import org.eclipse.emf.ecore.resource.ResourceSet;
import org.eclipse.xtend.lib.annotations.Accessors;
import org.eclipse.xtext.xbase.lib.Pure;

@SuppressWarnings("all")
public class EMFModelPatchApplier {
  private EMFModelAccess modelAccess;
  
  @Accessors
  private IdentifiedEMFObjectLocator locator;
  
  public EMFModelPatchApplier(final EMFModelAccess modelAccess) {
    this.modelAccess = modelAccess;
    IdentifiedEMFObjectLocator _identifiedEMFObjectLocator = new IdentifiedEMFObjectLocator();
    this.locator = _identifiedEMFObjectLocator;
  }
  
  public PatchApplication apply(final ModelPatch modelPatch, final ResourceSet input) {
    Preconditions.<ResourceSet>checkNotNull(input, "Input cannot be null");
    final EMFPatchApplication patchApplication = new EMFPatchApplication(modelPatch, this.modelAccess, input);
    patchApplication.setLocator(this.locator);
    patchApplication.apply();
    return patchApplication;
  }
  
  @Pure
  public IdentifiedEMFObjectLocator getLocator() {
    return this.locator;
  }
  
  public void setLocator(final IdentifiedEMFObjectLocator locator) {
    this.locator = locator;
  }
}
