/**
 * Copyright (c) 2016-2018 Thales Global Services S.A.S.
 * This program and the accompanying materials are made
 * available under the terms of the Eclipse Public License 2.0
 * which is available at https://www.eclipse.org/legal/epl-2.0/
 * 
 * SPDX-License-Identifier: EPL-2.0
 * 
 * Contributors:
 *   Abel Hegedus, Tamas Borbas, Balazs Grill, Peter Lunk, Daniel Segesdi (IncQuery Labs Ltd.) - initial API and implementation
 */
package org.eclipse.emf.diffmerge.patch.runtime.modelaccess;

import com.google.common.base.Optional;
import org.eclipse.emf.ecore.EClassifier;
import org.eclipse.emf.ecore.EObject;
import org.eclipse.emf.ecore.EStructuralFeature;

@SuppressWarnings("all")
public interface EMFModelAccess {
  /**
   * Creates a new model element with the specified type.
   */
  public abstract EObject create(final EClassifier type);
  
  /**
   * Adds an existing model element to a selected EReference.
   */
  public abstract void add(final EObject container, final EStructuralFeature feature, final Object element, final Optional<Integer> index);
  
  /**
   * Removes an object from the model.
   */
  public abstract void remove(final EObject element);
  
  /**
   * Removes an object from the 'many'-valued feature, or unsets the
   * 'single'-valued feature. If the feature is a containment reference,
   * the element is removed from the model as well.
   */
  public abstract void remove(final EObject container, final EStructuralFeature feature, final Object element, final Optional<Integer> index);
  
  /**
   * Moves an object inside an EStructuralFeature of an EObject to the specified index.
   */
  public abstract void changeIndex(final EObject container, final EStructuralFeature feature, final Object element, final Optional<Integer> newIndex);
}
