/**
 * Copyright (c) 2016-2018 Thales Global Services S.A.S.
 * This program and the accompanying materials are made
 * available under the terms of the Eclipse Public License 2.0
 * which is available at https://www.eclipse.org/legal/epl-2.0/
 * 
 * SPDX-License-Identifier: EPL-2.0
 * 
 * Contributors:
 *   Abel Hegedus, Tamas Borbas, Balazs Grill, Peter Lunk, Daniel Segesdi (IncQuery Labs Ltd.) - initial API and implementation
 */
package org.eclipse.emf.diffmerge.patch.ui.utils;

import com.google.common.base.Optional;
import java.util.ArrayList;
import java.util.List;
import org.eclipse.emf.diffmerge.patch.AttributeEntry;
import org.eclipse.emf.diffmerge.patch.ElementEntry;
import org.eclipse.emf.diffmerge.patch.ReferenceEntry;
import org.eclipse.emf.diffmerge.patch.StructuralFeatureEntry;
import org.eclipse.emf.diffmerge.patch.api.Identifiable;
import org.eclipse.emf.diffmerge.patch.api.ModelPatchEntry;
import org.eclipse.emf.diffmerge.patch.ui.utils.EntryPropertyWrapper;
import org.eclipse.emf.diffmerge.patch.ui.utils.IEntryLabelProvider;
import org.eclipse.xtend2.lib.StringConcatenation;
import org.eclipse.xtext.xbase.lib.CollectionLiterals;
import org.eclipse.xtext.xbase.lib.StringExtensions;

@SuppressWarnings("all")
public class DefaultEntryLabelProvider implements IEntryLabelProvider {
  @Override
  public String getLabel(final ModelPatchEntry entry) {
    return entry.toString();
  }
  
  @Override
  public String shortDescription(final ModelPatchEntry entry) {
    StringConcatenation _builder = new StringConcatenation();
    String _firstUpper = StringExtensions.toFirstUpper(entry.getDirection().toString().toLowerCase());
    _builder.append(_firstUpper);
    _builder.append(" ");
    String _firstUpper_1 = StringExtensions.toFirstUpper(entry.getEntryType().toString().toLowerCase());
    _builder.append(_firstUpper_1);
    return _builder.toString();
  }
  
  @Override
  public List<EntryPropertyWrapper> getPropertyList(final ModelPatchEntry entry) {
    final ArrayList<EntryPropertyWrapper> props = CollectionLiterals.<EntryPropertyWrapper>newArrayList();
    Identifiable _context = entry.getContext();
    EntryPropertyWrapper _entryPropertyWrapper = new EntryPropertyWrapper("context", _context);
    props.add(_entryPropertyWrapper);
    if ((entry instanceof ElementEntry)) {
      Identifiable _type = ((ElementEntry)entry).getType();
      EntryPropertyWrapper _entryPropertyWrapper_1 = new EntryPropertyWrapper("type", _type);
      props.add(_entryPropertyWrapper_1);
    }
    if ((entry instanceof StructuralFeatureEntry)) {
      Identifiable _feature = ((StructuralFeatureEntry)entry).getFeature();
      EntryPropertyWrapper _entryPropertyWrapper_2 = new EntryPropertyWrapper("feature", _feature);
      props.add(_entryPropertyWrapper_2);
      boolean _isPresent = ((StructuralFeatureEntry)entry).getIndex().isPresent();
      if (_isPresent) {
        Optional<Integer> _index = ((StructuralFeatureEntry)entry).getIndex();
        EntryPropertyWrapper _entryPropertyWrapper_3 = new EntryPropertyWrapper("index", _index);
        props.add(_entryPropertyWrapper_3);
      }
      if ((entry instanceof AttributeEntry)) {
        String _value = ((AttributeEntry)entry).getValue();
        EntryPropertyWrapper _entryPropertyWrapper_4 = new EntryPropertyWrapper("value", _value);
        props.add(_entryPropertyWrapper_4);
      } else {
        if ((entry instanceof ReferenceEntry)) {
          Identifiable _target = ((ReferenceEntry)entry).getTarget();
          EntryPropertyWrapper _entryPropertyWrapper_5 = new EntryPropertyWrapper("target", _target);
          props.add(_entryPropertyWrapper_5);
        }
      }
    }
    return props;
  }
}
